@@ -61,7 +61,7 @@ See the L<Rose::DB::Object::ConventionManager> documentation for more informatio
 
 =head1 AUTHOR
 
-John C. Siracusa (siracusa@mindspring.com)
+John C. Siracusa (siracusa@gmail.com)
 
 =head1 COPYRIGHT
 
