@@ -934,6 +934,7 @@ sub make_classes
 
     $meta->table($table);
     $meta->convention_manager($cm->clone);
+    $meta->db($db);
 
     $meta->auto_initialize(%args);
 
@@ -1400,7 +1401,7 @@ Returns a list (in list context) or reference to an array (in scalar context) of
 
 =head1 AUTHOR
 
-John C. Siracusa (siracusa@mindspring.com)
+John C. Siracusa (siracusa@gmail.com)
 
 =head1 COPYRIGHT
 
