@@ -10,7 +10,7 @@ use Rose::DB::Object::Metadata::UniqueKey;
 use Rose::DB::Object::Metadata::Auto;
 our @ISA = qw(Rose::DB::Object::Metadata::Auto);
 
-our $VERSION = '0.752';
+our $VERSION = '0.756';
 
 # syscolumns.coltype constants taken from:
 #
@@ -807,16 +807,6 @@ EOF
       my %key_columns;
       @key_columns{@local_cols} = @foreign_cols;
 
-
-      if(my $alt_key_name = $cm->auto_foreign_key_name($foreign_class, $key_name))
-      {
-        $key_name = $alt_key_name;
-      }
-      elsif($key_name !~ /^[a-zA-Z]\w*$/)
-      {
-        $key_name = undef;
-      }
-
       my $fk = 
         Rose::DB::Object::Metadata::ForeignKey->new(
           name        => $key_name,
@@ -832,16 +822,21 @@ EOF
     # foreign keys to work in a predictible manner.  This exact sort order
     # (lowercase table name comparisons) is part of the API for foreign
     # key auto generation.
-    #
-    # XXX: This is somewhat superseded by the convention manager, but it
-    # XXX: doesn't hurt to leave it here.
     @foreign_keys = 
       sort { lc $a->class->meta->table cmp lc $b->class->meta->table } 
       @foreign_keys;
 
+    my %used_names;
+
     foreach my $fk (@foreign_keys)
     {
-      my $name = $self->foreign_key_name_generator->($self, $fk);
+      my $name =
+        $cm->auto_foreign_key_name($fk->class, $fk->name, scalar $fk->key_columns, \%used_names);
+
+      unless(defined $name)
+      {
+        $fk->name($name = $self->foreign_key_name_generator->($self, $fk));
+      }
 
       unless(defined $name && $name =~ /^\w+$/)
       {
@@ -849,6 +844,8 @@ EOF
             "generated in $class for ", $fk->class;
       }
 
+      $used_names{$name}++;
+
       $fk->name($name);
     }
   };
