@@ -1876,7 +1876,7 @@ Returns the method maker method type for the column method type TYPE.
 
 =head1 AUTHOR
 
-John C. Siracusa (siracusa@mindspring.com)
+John C. Siracusa (siracusa@gmail.com)
 
 =head1 COPYRIGHT
 
