@@ -403,7 +403,7 @@ Get or set a boolean value that indicates whether or not L<triggers|Rose::DB::Ob
 
 =head1 AUTHOR
 
-John C. Siracusa (siracusa@mindspring.com)
+John C. Siracusa (siracusa@gmail.com)
 
 =head1 COPYRIGHT
 
